@@ -2,7 +2,7 @@
 """owyl -- Owyl Behavior Trees
 
 Behavior Trees are a form of U{hierarchical
-logic<http://aigamedev.com/hierarchical-logic}, and are quite useful
+logic<http://aigamedev.com/hierarchical-logic>}, and are quite useful
 and flexible for implementing game AI.
 
 Owyl implements a behavior tree using nested iterators/generators. A
@@ -38,13 +38,13 @@ Termination Status Values
   As mentioned, iterators in the tree may yield values of None, True,
   False, or a child iterator:
 
-  - B{None:} May be used to defer execution for another pass from the
-    scheduler. An iterator yielding None will be queried again.
+    - B{None:} May be used to defer execution for another pass from the
+      scheduler. An iterator yielding None will be queried again.
 
-  - B{True:} Termination value signalling successful execution.
+    - B{True:} Termination value signalling successful execution.
 
-  - B{False:} Termination value signalling unsuccessful execution, or
-    failure. Note: this is not considered an error value.
+    - B{False:} Termination value signalling unsuccessful execution, or
+      failure. Note: this is not considered an error value.
 
   True errors or exceptions should C{raise} the appropriate C{Error}
   or C{Exception}.
@@ -59,12 +59,13 @@ U{http://aigamedev.com/hierarchical-logic/advice-2}.
 Copyright 2008 David Eyk. All rights reserved.
 
 $Author: david.eyk $\n
-$Rev: 8 $\n
-$Date: 2009-01-05 20:12:51 -0600 (Mon, 05 Jan 2009) $
+$Rev: 26 $\n
+$Date: 2009-01-07 09:15:25 -0600 (Wed, 07 Jan 2009) $
 """
 
 __author__ = "$Author: david.eyk $"[9:-2]
-__revision__ = "$Rev: 8 $"[6:-2]
-__date__ = "$Date: 2009-01-05 20:12:51 -0600 (Mon, 05 Jan 2009) $"[7:-2]
+__revision__ = "$Rev: 26 $"[6:-2]
+__date__ = "$Date: 2009-01-07 09:15:25 -0600 (Wed, 07 Jan 2009) $"[7:-2]
 
 from core import *
+from decorators import *
